@@ -10,11 +10,16 @@ class Logger(BaseService):
         await self.Debug("Started")
         while True:
             await asyncio.sleep(0.1)
+    async def msb_signed_in(self, args):
+        pass
     
     async def StateUpdate(self, message):
         state = message.message[0]
         await self.Debug(f"Received: {message}")
 
+    async def _change_debug(self, message):
+        self.debug = message.message[0]
+ 
     async def _debug(self, message):
        self.printf(f"mSB:[{message.source}] {bcolors.OKGREEN}DEGUG:{bcolors.ENDC} {message.message[0]}")
        if self.debug:
